==> v2.6.5.1.tar.gz: gnosygnu_xowa/110_gfml/src_300_gdoc/gplx/gfml/GfmlDoc_.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx.gfml; import gplx.*;
public class GfmlDoc_ {
	public static GfmlDoc parse_any_eol_(String raw) {return parse_(String_.Replace(raw, String_.CrLf, String_.Lf));}
	public static GfmlDoc parse_(String raw) {
		GfmlBldr bldr = GfmlBldr_.default_();
		return bldr.XtoGfmlDoc(raw);
	}
}
class GfmlUsrMsgs {
	public static UsrMsg fail_HndTkn_alreadyExists()	{return UsrMsg.new_("hndTkn already exists");}
	public static UsrMsg fail_KeyTkn_alreadyExists()	{return UsrMsg.new_("keyTkn already exists");}
	public static UsrMsg fail_DatTkn_notFound()			{return UsrMsg.new_("datTkn not found");}
	public static UsrMsg fail_Frame_danglingBgn()		{return UsrMsg.new_("dangling frame");}
	public static void MakeErr(GfmlBldr bldr, UsrMsg um, String raw) {
		bldr.Doc().UsrMsgs().Add(um);
		GfmlStringHighlighter sh = GfmlStringHighlighter.new_();
		sh.Raw_(raw).Mark_(bldr.StreamPos(), '*', "failed");
		um.Add("errorPos", bldr.StreamPos());
		um.Add("errorHighlight", String_.CrLf + String_.Concat_lines_crlf(sh.Gen()));
	}
	public static Err gfmlParseError(GfmlBldr bldr) {
		Err rv = Err_.new_("gfml parse error");
		for (int i = 0; i < bldr.Doc().UsrMsgs().Count(); i++) {
			UsrMsg um = (UsrMsg)bldr.Doc().UsrMsgs().Get_at(i);
			rv.Add("err" + Int_.Xto_str(i), um.XtoStr());
		}
		return rv;
	}
}

==> v2.7.2.1.tar.gz: gnosygnu_xowa/110_gfml/src_300_gdoc/gplx/gfml/GfmlDoc_.java <==
/*
XOWA: the XOWA Offline Wiki Application
Copyright (C) 2012 gnosygnu@gmail.com

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
package gplx.gfml; import gplx.*;
public class GfmlDoc_ {
	public static GfmlDoc parse_any_eol_(String raw) {return parse_(String_.Replace(raw, String_.CrLf, String_.Lf));}
	public static GfmlDoc parse_(String raw) {
		GfmlBldr bldr = GfmlBldr_.default_();
		return bldr.XtoGfmlDoc(raw);
	}
}
class GfmlUsrMsgs {
	public static UsrMsg fail_HndTkn_alreadyExists()	{return UsrMsg.new_("hndTkn already exists");}
	public static UsrMsg fail_KeyTkn_alreadyExists()	{return UsrMsg.new_("keyTkn already exists");}
	public static UsrMsg fail_DatTkn_notFound()			{return UsrMsg.new_("datTkn not found");}
	public static UsrMsg fail_Frame_danglingBgn()		{return UsrMsg.new_("dangling frame");}
	public static void MakeErr(GfmlBldr bldr, UsrMsg um, String raw) {
		bldr.Doc().UsrMsgs().Add(um);
		GfmlStringHighlighter sh = GfmlStringHighlighter.new_();
		sh.Raw_(raw).Mark_(bldr.StreamPos(), '*', "failed");
		um.Add("errorPos", bldr.StreamPos());
		um.Add("errorHighlight", String_.CrLf + String_.Concat_lines_crlf(sh.Gen()));
	}
	public static Exc gfmlParseError(GfmlBldr bldr) {
		Exc rv = Exc_.new_("gfml parse error");
		for (int i = 0; i < bldr.Doc().UsrMsgs().Count(); i++) {
			UsrMsg um = (UsrMsg)bldr.Doc().UsrMsgs().Get_at(i);
			rv.Args_add("err" + Int_.Xto_str(i), um.XtoStr());
		}
		return rv;
	}
}
